==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/JobInputHttpArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.JobInputHttpArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Represents HTTPS job input.
 * @property baseUri Base URI for HTTPS job input. It will be concatenated with provided file names. If no base uri is given, then the provided file list is assumed to be fully qualified uris. Maximum length of 4000 characters. The query strings will not be returned in service responses to prevent sensitive data exposure.
 * @property end Defines a point on the timeline of the input media at which processing will end. Defaults to the end of the input media.
 * @property files List of files. Required for JobInputHttp. Maximum of 4000 characters each. Query strings will not be returned in service responses to prevent sensitive data exposure.
 * @property inputDefinitions Defines a list of InputDefinitions. For each InputDefinition, it defines a list of track selections and related metadata.
 * @property label A label that is assigned to a JobInputClip, that is used to satisfy a reference used in the Transform. For example, a Transform can be authored so as to take an image file with the label 'xyz' and apply it as an overlay onto the input video before it is encoded. When submitting a Job, exactly one of the JobInputs should be the image file, and it should have the label 'xyz'.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.JobInputHttp'.
 * @property start Defines a point on the timeline of the input media at which processing will start. Defaults to the beginning of the input media.
 */
public data class JobInputHttpArgs(
    public val baseUri: Output<String>? = null,
    public val end: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>? = null,
    public val files: Output<List<String>>? = null,
    public val inputDefinitions: Output<List<Any>>? = null,
    public val label: Output<String>? = null,
    public val odataType: Output<String>,
    public val start: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.JobInputHttpArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.JobInputHttpArgs =
        com.pulumi.azurenative.media.inputs.JobInputHttpArgs.builder()
            .baseUri(baseUri?.applyValue({ args0 -> args0 }))
            .end(
                end?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .files(files?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .inputDefinitions(inputDefinitions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .label(label?.applyValue({ args0 -> args0 }))
            .odataType(odataType.applyValue({ args0 -> args0 }))
            .start(
                start?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [JobInputHttpArgs].
 */
@PulumiTagMarker
public class JobInputHttpArgsBuilder internal constructor() {
    private var baseUri: Output<String>? = null

    private var end: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>? = null

    private var files: Output<List<String>>? = null

    private var inputDefinitions: Output<List<Any>>? = null

    private var label: Output<String>? = null

    private var odataType: Output<String>? = null

    private var start: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>? = null

    /**
     * @param value Base URI for HTTPS job input. It will be concatenated with provided file names. If no base uri is given, then the provided file list is assumed to be fully qualified uris. Maximum length of 4000 characters. The query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("rrsvqidfvvvsbgrf")
    public suspend fun baseUri(`value`: Output<String>) {
        this.baseUri = value
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will end. Defaults to the end of the input media.
     */
    @JvmName("wjgxwmerpjmjbmeo")
    public suspend fun end(`value`: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>) {
        this.end = value
    }

    /**
     * @param value List of files. Required for JobInputHttp. Maximum of 4000 characters each. Query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("mnlnxempxdawrplh")
    public suspend fun files(`value`: Output<List<String>>) {
        this.files = value
    }

    @JvmName("ibavfvhetnbephta")
    public suspend fun files(vararg values: Output<String>) {
        this.files = Output.all(values.asList())
    }

    /**
     * @param values List of files. Required for JobInputHttp. Maximum of 4000 characters each. Query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("owtmbrxxvvtccfnp")
    public suspend fun files(values: List<Output<String>>) {
        this.files = Output.all(values)
    }

    /**
     * @param value Defines a list of InputDefinitions. For each InputDefinition, it defines a list of track selections and related metadata.
     */
    @JvmName("xayghpryvtnflmir")
    public suspend fun inputDefinitions(`value`: Output<List<Any>>) {
        this.inputDefinitions = value
    }

    @JvmName("fydoeaxutacjguql")
    public suspend fun inputDefinitions(vararg values: Output<Any>) {
        this.inputDefinitions = Output.all(values.asList())
    }

    /**
     * @param values Defines a list of InputDefinitions. For each InputDefinition, it defines a list of track selections and related metadata.
     */
    @JvmName("xixhgfragkhvcchu")
    public suspend fun inputDefinitions(values: List<Output<Any>>) {
        this.inputDefinitions = Output.all(values)
    }

    /**
     * @param value A label that is assigned to a JobInputClip, that is used to satisfy a reference used in the Transform. For example, a Transform can be authored so as to take an image file with the label 'xyz' and apply it as an overlay onto the input video before it is encoded. When submitting a Job, exactly one of the JobInputs should be the image file, and it should have the label 'xyz'.
     */
    @JvmName("jfyqfyoiwwpotyrb")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.JobInputHttp'.
     */
    @JvmName("slwrykloxyycoovj")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will start. Defaults to the beginning of the input media.
     */
    @JvmName("uraytpgxuvpfvjty")
    public suspend fun start(`value`: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>) {
        this.start = value
    }

    /**
     * @param value Base URI for HTTPS job input. It will be concatenated with provided file names. If no base uri is given, then the provided file list is assumed to be fully qualified uris. Maximum length of 4000 characters. The query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("wouxlfominhxxxan")
    public suspend fun baseUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baseUri = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will end. Defaults to the end of the input media.
     */
    @JvmName("irpfnqbgadgdivot")
    public suspend fun end(`value`: Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will end. Defaults to the end of the input media.
     */
    @JvmName("dxhnypevaggugtni")
    public fun end(`value`: AbsoluteClipTimeArgs) {
        val toBeMapped = Either.ofLeft<AbsoluteClipTimeArgs, UtcClipTimeArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will end. Defaults to the end of the input media.
     */
    @JvmName("kefaurmsouaohbka")
    public fun end(`value`: UtcClipTimeArgs) {
        val toBeMapped = Either.ofRight<AbsoluteClipTimeArgs, UtcClipTimeArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value List of files. Required for JobInputHttp. Maximum of 4000 characters each. Query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("ifduomshtoggslst")
    public suspend fun files(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.files = mapped
    }

    /**
     * @param values List of files. Required for JobInputHttp. Maximum of 4000 characters each. Query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("rjxdstidyaqjtusg")
    public suspend fun files(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.files = mapped
    }

    /**
     * @param value Defines a list of InputDefinitions. For each InputDefinition, it defines a list of track selections and related metadata.
     */
    @JvmName("iyuccurdebqcwwio")
    public suspend fun inputDefinitions(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.inputDefinitions = mapped
    }

    /**
     * @param values Defines a list of InputDefinitions. For each InputDefinition, it defines a list of track selections and related metadata.
     */
    @JvmName("qhhngodmgdhwrsbr")
    public suspend fun inputDefinitions(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputDefinitions = mapped
    }

    /**
     * @param value A label that is assigned to a JobInputClip, that is used to satisfy a reference used in the Transform. For example, a Transform can be authored so as to take an image file with the label 'xyz' and apply it as an overlay onto the input video before it is encoded. When submitting a Job, exactly one of the JobInputs should be the image file, and it should have the label 'xyz'.
     */
    @JvmName("wgixnxgvuoqcbruu")
    public suspend fun label(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.JobInputHttp'.
     */
    @JvmName("kbuckcbsyfncqdqd")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will start. Defaults to the beginning of the input media.
     */
    @JvmName("fdoebhvnuiycryxk")
    public suspend fun start(`value`: Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will start. Defaults to the beginning of the input media.
     */
    @JvmName("bcekuvpwxsliyuxi")
    public fun start(`value`: AbsoluteClipTimeArgs) {
        val toBeMapped = Either.ofLeft<AbsoluteClipTimeArgs, UtcClipTimeArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.start = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will start. Defaults to the beginning of the input media.
     */
    @JvmName("jxmdnsrrhxwfcqar")
    public fun start(`value`: UtcClipTimeArgs) {
        val toBeMapped = Either.ofRight<AbsoluteClipTimeArgs, UtcClipTimeArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): JobInputHttpArgs = JobInputHttpArgs(
        baseUri = baseUri,
        end = end,
        files = files,
        inputDefinitions = inputDefinitions,
        label = label,
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        start = start,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/JobInputHttpArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.JobInputHttpArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Represents HTTPS job input.
 * @property baseUri Base URI for HTTPS job input. It will be concatenated with provided file names. If no base uri is given, then the provided file list is assumed to be fully qualified uris. Maximum length of 4000 characters. The query strings will not be returned in service responses to prevent sensitive data exposure.
 * @property end Defines a point on the timeline of the input media at which processing will end. Defaults to the end of the input media.
 * @property files List of files. Required for JobInputHttp. Maximum of 4000 characters each. Query strings will not be returned in service responses to prevent sensitive data exposure.
 * @property inputDefinitions Defines a list of InputDefinitions. For each InputDefinition, it defines a list of track selections and related metadata.
 * @property label A label that is assigned to a JobInputClip, that is used to satisfy a reference used in the Transform. For example, a Transform can be authored so as to take an image file with the label 'xyz' and apply it as an overlay onto the input video before it is encoded. When submitting a Job, exactly one of the JobInputs should be the image file, and it should have the label 'xyz'.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.JobInputHttp'.
 * @property start Defines a point on the timeline of the input media at which processing will start. Defaults to the beginning of the input media.
 */
public data class JobInputHttpArgs(
    public val baseUri: Output<String>? = null,
    public val end: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>? = null,
    public val files: Output<List<String>>? = null,
    public val inputDefinitions: Output<List<Any>>? = null,
    public val label: Output<String>? = null,
    public val odataType: Output<String>,
    public val start: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.JobInputHttpArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.JobInputHttpArgs =
        com.pulumi.azurenative.media.inputs.JobInputHttpArgs.builder()
            .baseUri(baseUri?.applyValue({ args0 -> args0 }))
            .end(
                end?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .files(files?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .inputDefinitions(inputDefinitions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .label(label?.applyValue({ args0 -> args0 }))
            .odataType(odataType.applyValue({ args0 -> args0 }))
            .start(
                start?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [JobInputHttpArgs].
 */
@PulumiTagMarker
public class JobInputHttpArgsBuilder internal constructor() {
    private var baseUri: Output<String>? = null

    private var end: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>? = null

    private var files: Output<List<String>>? = null

    private var inputDefinitions: Output<List<Any>>? = null

    private var label: Output<String>? = null

    private var odataType: Output<String>? = null

    private var start: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>? = null

    /**
     * @param value Base URI for HTTPS job input. It will be concatenated with provided file names. If no base uri is given, then the provided file list is assumed to be fully qualified uris. Maximum length of 4000 characters. The query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("dbsmgaobeexjrhan")
    public suspend fun baseUri(`value`: Output<String>) {
        this.baseUri = value
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will end. Defaults to the end of the input media.
     */
    @JvmName("suphvtcmfepwattg")
    public suspend fun end(`value`: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>) {
        this.end = value
    }

    /**
     * @param value List of files. Required for JobInputHttp. Maximum of 4000 characters each. Query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("hcxguimorogbsiov")
    public suspend fun files(`value`: Output<List<String>>) {
        this.files = value
    }

    @JvmName("ujmjpuaswlpbpwil")
    public suspend fun files(vararg values: Output<String>) {
        this.files = Output.all(values.asList())
    }

    /**
     * @param values List of files. Required for JobInputHttp. Maximum of 4000 characters each. Query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("qfpvfniokqxdvjkn")
    public suspend fun files(values: List<Output<String>>) {
        this.files = Output.all(values)
    }

    /**
     * @param value Defines a list of InputDefinitions. For each InputDefinition, it defines a list of track selections and related metadata.
     */
    @JvmName("fkdmkagpuhytssvw")
    public suspend fun inputDefinitions(`value`: Output<List<Any>>) {
        this.inputDefinitions = value
    }

    @JvmName("vgfwrwyvmhflimbp")
    public suspend fun inputDefinitions(vararg values: Output<Any>) {
        this.inputDefinitions = Output.all(values.asList())
    }

    /**
     * @param values Defines a list of InputDefinitions. For each InputDefinition, it defines a list of track selections and related metadata.
     */
    @JvmName("nmfxpwyopogbiveb")
    public suspend fun inputDefinitions(values: List<Output<Any>>) {
        this.inputDefinitions = Output.all(values)
    }

    /**
     * @param value A label that is assigned to a JobInputClip, that is used to satisfy a reference used in the Transform. For example, a Transform can be authored so as to take an image file with the label 'xyz' and apply it as an overlay onto the input video before it is encoded. When submitting a Job, exactly one of the JobInputs should be the image file, and it should have the label 'xyz'.
     */
    @JvmName("aucljbwcwdwoxsop")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.JobInputHttp'.
     */
    @JvmName("lkughplwqssbsxpc")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will start. Defaults to the beginning of the input media.
     */
    @JvmName("irrjqermetrnwnio")
    public suspend fun start(`value`: Output<Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>>) {
        this.start = value
    }

    /**
     * @param value Base URI for HTTPS job input. It will be concatenated with provided file names. If no base uri is given, then the provided file list is assumed to be fully qualified uris. Maximum length of 4000 characters. The query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("eodphjtqhlxvhhhd")
    public suspend fun baseUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baseUri = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will end. Defaults to the end of the input media.
     */
    @JvmName("fagetgmwuqncxlau")
    public suspend fun end(`value`: Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will end. Defaults to the end of the input media.
     */
    @JvmName("oifoftanxkpbjwgi")
    public fun end(`value`: AbsoluteClipTimeArgs) {
        val toBeMapped = Either.ofLeft<AbsoluteClipTimeArgs, UtcClipTimeArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will end. Defaults to the end of the input media.
     */
    @JvmName("qiurwodwnyeekkxa")
    public fun end(`value`: UtcClipTimeArgs) {
        val toBeMapped = Either.ofRight<AbsoluteClipTimeArgs, UtcClipTimeArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value List of files. Required for JobInputHttp. Maximum of 4000 characters each. Query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("cwawrjvbdvssdvud")
    public suspend fun files(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.files = mapped
    }

    /**
     * @param values List of files. Required for JobInputHttp. Maximum of 4000 characters each. Query strings will not be returned in service responses to prevent sensitive data exposure.
     */
    @JvmName("glrcnpoycthodplb")
    public suspend fun files(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.files = mapped
    }

    /**
     * @param value Defines a list of InputDefinitions. For each InputDefinition, it defines a list of track selections and related metadata.
     */
    @JvmName("etbfhrjkpuycoymj")
    public suspend fun inputDefinitions(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.inputDefinitions = mapped
    }

    /**
     * @param values Defines a list of InputDefinitions. For each InputDefinition, it defines a list of track selections and related metadata.
     */
    @JvmName("qensgwscxdhterxi")
    public suspend fun inputDefinitions(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputDefinitions = mapped
    }

    /**
     * @param value A label that is assigned to a JobInputClip, that is used to satisfy a reference used in the Transform. For example, a Transform can be authored so as to take an image file with the label 'xyz' and apply it as an overlay onto the input video before it is encoded. When submitting a Job, exactly one of the JobInputs should be the image file, and it should have the label 'xyz'.
     */
    @JvmName("brmcrhscwjacrgfp")
    public suspend fun label(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.JobInputHttp'.
     */
    @JvmName("gxdxqqaiqpigiwoj")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will start. Defaults to the beginning of the input media.
     */
    @JvmName("rgxqijpfsnbnntqd")
    public suspend fun start(`value`: Either<AbsoluteClipTimeArgs, UtcClipTimeArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will start. Defaults to the beginning of the input media.
     */
    @JvmName("qscdpoiplgqrsbjh")
    public fun start(`value`: AbsoluteClipTimeArgs) {
        val toBeMapped = Either.ofLeft<AbsoluteClipTimeArgs, UtcClipTimeArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.start = mapped
    }

    /**
     * @param value Defines a point on the timeline of the input media at which processing will start. Defaults to the beginning of the input media.
     */
    @JvmName("ebuogvwfrssbbyyo")
    public fun start(`value`: UtcClipTimeArgs) {
        val toBeMapped = Either.ofRight<AbsoluteClipTimeArgs, UtcClipTimeArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): JobInputHttpArgs = JobInputHttpArgs(
        baseUri = baseUri,
        end = end,
        files = files,
        inputDefinitions = inputDefinitions,
        label = label,
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        start = start,
    )
}
